@@ -709,6 +709,13 @@ hdf5_save_object (SEXP call, hid_t fid, const char *symname, SEXP val)
     }
   else if (isNull (val))
     {
+      hid_t gid;
+
+      if ((gid = H5Gcreate (fid, symname, 0)) < 0)
+        errorcall (call, "unable to create group");
+      
+      if (H5Gclose (gid) < 0)
+        errorcall (call, "unable to close group");
     }
   else
     {
